import sys
import argparse
from trmloc_input_builder import main as trmloc_input_builder

def main(argv):

    def str2bool(v):
        if v.lower() in ("True", "TRUE", "yes", "true", "t", "y", "1"):
            return True
        elif v.lower() in ("False", "FALSE", "no", "false", "f", "n", "0"):
            return False
        else:
            raise argparse.ArgumentTypeError("Boolean value expected.")
    def parse_int_with_nan(value):
        try:
            return int(value)
        except ValueError:
            return float('nan')
    def parse_float_with_nan(value):
        try:
            return float(value)
        except ValueError:
            return float('nan')

    parser = argparse.ArgumentParser()
    parser.add_argument("network_inventory_path", help="Path to input file of type inventory")
    parser.add_argument("picks_path", help="Path to the picks file")
    parser.add_argument("--velocity_model_file_path", help="Path to the velocity model file", type=str, required=True)
    parser.add_argument("--latitude", help="Event latitude", type=parse_float_with_nan, required=True)
    parser.add_argument("--longitude", help="Event longitude", type=parse_float_with_nan, required=True)
    parser.add_argument("--depth", help="Event depth in kilometers", type=parse_float_with_nan, required=True)
    parser.add_argument("--event_name", help="Name of the event", type=str, required=True)
    parser.add_argument("--fvi", help="FVI parameter", type=parse_int_with_nan, required=True)
    parser.add_argument("--fdi", help="FDI parameter", type=parse_int_with_nan, required=True)
    parser.add_argument("--fpo", help="FPO parameter", type=parse_int_with_nan, required=True)
    parser.add_argument("--err", help="Error parameter", type=parse_int_with_nan, required=True)
    parser.add_argument("--cme", help="CME parameter", type=parse_float_with_nan, required=True)
    parser.add_argument("--cmz", help="CMZ parameter", type=parse_float_with_nan, required=True)
    parser.add_argument("--ia", help="IA parameter", type=str, required=True) 
    parser.add_argument("--ip", help="IP parameter", type=str, required=True)
    parser.add_argument("--cp", help="CP parameter", type=parse_float_with_nan, required=True)
    parser.add_argument("--omp", help="OMP parameter", type=parse_int_with_nan, required=True)
    parser.add_argument("--fi", help="FI parameter", type=parse_int_with_nan, required=True)
    parser.add_argument("--fh", help="FH parameter", type=parse_float_with_nan, required=True)
    parser.add_argument("--cp_min", help="CP_MIN parameter", type=parse_float_with_nan, required=True)
    parser.add_argument("--cp_max", help="CP_MAX parameter", type=parse_float_with_nan, required=True)
    parser.add_argument("--cpi", help="CPI parameter", type=parse_float_with_nan, required=True)
    parser.add_argument("--cpf", help="CPF parameter", type=parse_int_with_nan, required=False)
    parser.add_argument("--ftm", help="FTM parameter", type=parse_float_with_nan, required=True)
    parser.add_argument("--fit", help="FIT parameter", type=parse_int_with_nan, required=True)
    parser.add_argument("--fsc", help="FSC parameter", type=parse_float_with_nan, required=True)
    parser.add_argument("--fec", help="FEC parameter", type=parse_float_with_nan, required=True)
    parser.add_argument("--m", help="M parameter", type=str2bool, required=True)
    parser.add_argument("--e", help="E parameter", type=str2bool, required=True)
    parser.add_argument("--xstep", help="X step size", type=parse_int_with_nan, required=True)
    parser.add_argument("--ystep", help="Y step size", type=parse_int_with_nan, required=True)
    parser.add_argument("--z1", help="Z1 parameter", type=parse_int_with_nan, required=True)
    parser.add_argument("--z2", help="Z2 parameter", type=parse_int_with_nan, required=True)
    parser.add_argument("--zstep", help="Z step size", type=parse_int_with_nan, required=True)
    parser.add_argument("--log_file_name", help="log file name", type=str, required=True)
    parser.add_argument("--out_file_name", help="out file name", type=str, required=True)
    parser.add_argument("--res_file_name", help="res file name", type=str, required=True)
    parser.add_argument("--xcp_file_name", help="xcp file name", type=str, required=True)
    parser.add_argument("--input_par_file_name", help="input params file name", type=str, required=True)

    args = parser.parse_args()
    trmloc_input_builder(**vars(args))
    return

if __name__ == '__main__':
    main(sys.argv)